@@ -3,26 +3,12 @@
  *
  * Author: Jorn Baayen <jorn@openedhand.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #ifndef GUPNP_SERVICE_PROXY_H
 #define GUPNP_SERVICE_PROXY_H
 
-#include "gupnp-error.h"
 #include "gupnp-service-info.h"
 
 G_BEGIN_DECLS
@@ -43,14 +29,21 @@ struct _GUPnPServiceProxyClass {
         GUPnPServiceInfoClass parent_class;
 
         /* signals */
+        /**
+         * subscription_lost:
+         *
+         * Test
+         */
         void (* subscription_lost) (GUPnPServiceProxy *proxy,
                                     const GError      *reason);
 
+#ifndef GOBJECT_INTROSPECTION_SKIP
         /* future padding */
         void (* _gupnp_reserved1) (void);
         void (* _gupnp_reserved2) (void);
         void (* _gupnp_reserved3) (void);
         void (* _gupnp_reserved4) (void);
+#endif
 };
 
 /**
@@ -60,6 +53,18 @@ struct _GUPnPServiceProxyClass {
  **/
 typedef struct _GUPnPServiceProxyAction GUPnPServiceProxyAction;
 
+G_DECLARE_FINAL_TYPE (GUPnPServiceProxyActionIter,
+                      gupnp_service_proxy_action_iter,
+                      GUPNP,
+                      SERVICE_PROXY_ACTION_ITER,
+                      GObject);
+/**
+ * GUPnPServiceProxyActionIter:
+ *
+ * An opaque object representing an iterator over the out parameters of an action
+ * Since: 1.6.6
+ **/
+
 /**
  * GUPnPServiceProxyActionCallback:
  * @proxy: The #GUPnPServiceProxy @action is called from
@@ -68,6 +73,7 @@ typedef struct _GUPnPServiceProxyAction GUPnPServiceProxyAction;
  *
  * Callback notifying that @action on @proxy has returned and
  * gupnp_service_proxy_end_action() etc can be called.
+ * Deprecated: 1.2.0
  **/
 typedef void (* GUPnPServiceProxyActionCallback) (
                                      GUPnPServiceProxy       *proxy,
@@ -89,86 +95,6 @@ typedef void (* GUPnPServiceProxyNotifyCallback) (GUPnPServiceProxy *proxy,
                                                   GValue            *value,
                                                   gpointer           user_data);
 
-G_DEPRECATED gboolean
-gupnp_service_proxy_send_action    (GUPnPServiceProxy              *proxy,
-                                    const char                     *action,
-                                    GError                        **error,
-                                    ...) G_GNUC_NULL_TERMINATED;
-
-G_DEPRECATED gboolean
-gupnp_service_proxy_send_action_valist
-                                   (GUPnPServiceProxy              *proxy,
-                                    const char                     *action,
-                                    GError                        **error,
-                                    va_list                         var_args);
-
-G_DEPRECATED gboolean
-gupnp_service_proxy_send_action_list (GUPnPServiceProxy *proxy,
-                                      const char        *action,
-                                      GList             *in_names,
-                                      GList             *in_values,
-                                      GList             *out_names,
-                                      GList             *out_types,
-                                      GList            **out_values,
-                                      GError           **error);
-
-G_DEPRECATED GUPnPServiceProxyAction *
-gupnp_service_proxy_begin_action   (GUPnPServiceProxy              *proxy,
-                                    const char                     *action,
-                                    GUPnPServiceProxyActionCallback callback,
-                                    gpointer                        user_data,
-                                    ...) G_GNUC_NULL_TERMINATED;
-
-G_DEPRECATED GUPnPServiceProxyAction *
-gupnp_service_proxy_begin_action_valist
-                                   (GUPnPServiceProxy              *proxy,
-                                    const char                     *action,
-                                    GUPnPServiceProxyActionCallback callback,
-                                    gpointer                        user_data,
-                                    va_list                         var_args);
-
-G_DEPRECATED GUPnPServiceProxyAction *
-gupnp_service_proxy_begin_action_list
-                                   (GUPnPServiceProxy              *proxy,
-                                    const char                     *action,
-                                    GList                          *in_names,
-                                    GList                          *in_values,
-                                    GUPnPServiceProxyActionCallback callback,
-                                    gpointer                        user_data);
-
-G_DEPRECATED gboolean
-gupnp_service_proxy_end_action     (GUPnPServiceProxy              *proxy,
-                                    GUPnPServiceProxyAction        *action,
-                                    GError                        **error,
-                                    ...) G_GNUC_NULL_TERMINATED;
-
-G_DEPRECATED gboolean
-gupnp_service_proxy_end_action_valist
-                                   (GUPnPServiceProxy              *proxy,
-                                    GUPnPServiceProxyAction        *action,
-                                    GError                        **error,
-                                    va_list                         var_args);
-
-G_DEPRECATED gboolean
-gupnp_service_proxy_end_action_list
-                                  (GUPnPServiceProxy       *proxy,
-                                   GUPnPServiceProxyAction *action,
-                                   GList                   *out_names,
-                                   GList                   *out_types,
-                                   GList                  **out_values,
-                                   GError                  **error);
-
-G_DEPRECATED gboolean
-gupnp_service_proxy_end_action_hash
-                                   (GUPnPServiceProxy              *proxy,
-                                    GUPnPServiceProxyAction        *action,
-                                    GHashTable                     *hash,
-                                    GError                        **error);
-
-G_DEPRECATED void
-gupnp_service_proxy_cancel_action  (GUPnPServiceProxy              *proxy,
-                                    GUPnPServiceProxyAction        *action);
-
 gboolean
 gupnp_service_proxy_add_notify     (GUPnPServiceProxy              *proxy,
                                     const char                     *variable,
@@ -215,6 +141,9 @@ GUPnPServiceProxyAction *
 gupnp_service_proxy_action_new (const char *action,
                                 ...) G_GNUC_NULL_TERMINATED;
 
+GUPnPServiceProxyAction *
+gupnp_service_proxy_action_new_plain (const char *action);
+
 GUPnPServiceProxyAction *
 gupnp_service_proxy_action_new_from_list (const char *action,
                                           GList      *in_names,
@@ -229,6 +158,30 @@ gupnp_service_proxy_action_unref (GUPnPServiceProxyAction *action);
 G_DEFINE_AUTOPTR_CLEANUP_FUNC (GUPnPServiceProxyAction,
                                gupnp_service_proxy_action_unref)
 
+GUPnPServiceProxyAction *
+gupnp_service_proxy_action_add_argument (GUPnPServiceProxyAction *action,
+                                         const char *name,
+                                         const GValue *value);
+
+gboolean
+gupnp_service_proxy_action_set (GUPnPServiceProxyAction *action,
+                                const char *key,
+                                const GValue *value,
+                                GError **error);
+
+GUPnPServiceProxyActionIter *
+gupnp_service_proxy_action_iterate (GUPnPServiceProxyAction *action,
+                                    GError **error);
+
+gboolean
+gupnp_service_proxy_action_iter_next (GUPnPServiceProxyActionIter *self);
+
+const char *
+gupnp_service_proxy_action_iter_get_name (GUPnPServiceProxyActionIter *self);
+
+gboolean
+gupnp_service_proxy_action_iter_get_value (GUPnPServiceProxyActionIter *self,
+                                           GValue *value);
 gboolean
 gupnp_service_proxy_action_get_result (GUPnPServiceProxyAction *action,
                                        GError                 **error,
@@ -265,6 +218,11 @@ gupnp_service_proxy_call_action (GUPnPServiceProxy       *proxy,
                                  GCancellable            *cancellable,
                                  GError                 **error);
 
+void
+gupnp_service_proxy_set_credentials (GUPnPServiceProxy *proxy,
+                                     const char        *user,
+                                     const char        *password);
+
 G_END_DECLS
 
 #endif /* GUPNP_SERVICE_PROXY_H */
